@@ -170,7 +170,7 @@
 ###########
   if(missing(geodata))
     geodata <- list(coords=coords, data=data, units.m=units.m)
-  require(mva)
+  if(!("package:stats" %in% search())) require("mva")
   call.fc <- match.call()
   seed <- get(".Random.seed", envir=.GlobalEnv, inherits = FALSE)
   do.prediction <- ifelse(all(locations == "no"), FALSE, TRUE)
